aboutsummaryrefslogtreecommitdiffstats
path: root/sources/shiboken6/ApiExtractor/abstractmetatype.h
diff options
context:
space:
mode:
Diffstat (limited to 'sources/shiboken6/ApiExtractor/abstractmetatype.h')
-rw-r--r--sources/shiboken6/ApiExtractor/abstractmetatype.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/sources/shiboken6/ApiExtractor/abstractmetatype.h b/sources/shiboken6/ApiExtractor/abstractmetatype.h
index bb75cc069..6aa682e04 100644
--- a/sources/shiboken6/ApiExtractor/abstractmetatype.h
+++ b/sources/shiboken6/ApiExtractor/abstractmetatype.h
@@ -217,8 +217,11 @@ public:
/// Checks if the type is an Object/QObject or pointer to Value Type.
/// In other words, tells if the type is "T*" and T has a Python wrapper.
bool isPointerToWrapperType() const;
- /// Checks if a meta type should be dereferenced by the Python method wrapper passing it to C++.
- bool shouldDereferencePointer() const;
+ /// Wrapper type passed by reference
+ bool isWrapperPassedByReference() const;
+ /// Checks if the meta type of an argument should be dereferenced by the Python
+ /// method wrapper passing it to C++.
+ bool shouldDereferenceArgument() const;
/// Returns true if the type is a C++ integral primitive,
/// i.e. bool, char, int, long, and their unsigned counterparts.
bool isCppIntegralPrimitive() const;